@@ -12,9 +12,13 @@ __version__ = _version_file.read_text().strip()
 def setup(app: Sphinx):
     """Set up extension, directives and events."""
     state = SphinxCodeAutoLink()
+    app.setup_extension('sphinx.ext.autodoc')
     app.add_css_file('sphinx-codeautolink.css')
     app.add_config_value('codeautolink_autodoc_inject', True, 'html', types=[bool])
     app.add_config_value('codeautolink_global_preface', '', 'html', types=[str])
+    app.add_config_value('codeautolink_custom_blocks', {}, 'html', types=[dict])
+    app.add_config_value('codeautolink_concat_default', False, 'html', types=[bool])
+    app.add_config_value('codeautolink_search_css_classes', [], 'html', types=[list])
 
     app.add_directive('autolink-concat', directive.Concat)
     app.add_directive('autolink-examples', directive.Examples)
